@@ -718,38 +718,6 @@ sub table_of_contents {
     return @toc;
 }
 
-=head3 html_toc
-
-The HTML formatted table of contents.
-
-=cut
-
-sub html_toc {
-    my $self = shift;
-    return "" unless $self->is_html;
-    my @toc = $self->table_of_contents;
-    return "" unless @toc;
-    # do the dirty job
-    my @out;
-    foreach my $item (@toc) {
-        # given that we wrap this into <a>, we have to strip eventual ones
-
-        my $string = $item->{string};
-        $string =~ s!<a [^>]+?>!!g;
-        $string =~ s!</a>!!g;
-
-        my $line = qq{<p class="tableofcontentline toclevel} .
-          $item->{level} . qq{"><span class="tocprefix">} .
-          "&nbsp;&nbsp;" x  $item->{level} . "</span>" .
-            qq{<a href="#toc} . $item->{index} . qq{">} .
-              $string . "</a></p>";
-        push @out, $line;
-    }
-    return join ("\n", @out) . "\n";
-}
-
-
-
 =head3 manage_verse
 
 =cut
