@@ -38,24 +38,18 @@ sub string {
     return shift->{_raw_string};
 }
 
-=head3 document
+=head3 elements
 
 It returns the only L<Text::Amuse::Element> which composes the body.
 
 =cut
 
 
-sub document {
+sub elements {
     my $self = shift;
-    my $el = Text::Amuse::Element->new($self->string);
-
-    # restore the mangling;
-    my $string = $el->string;
-    my $removed = $el->removed;
-    $el->string($removed . $string);
-    $el->removed("");
-    $el->type("standalone");
-    return $el;
+    my $el = Text::Amuse::Element->new(type => 'standalone',
+                                       string => $self->string);
+    return ($el);
 }
 
 =head2 Fake methods
